@@ -1,19 +1,25 @@
 #!/bin/sh
 
-VERSION="3.0.0"
-MAJOR_MINOR="3.0"
+VERSION="3.2.0"
+MAJOR_MINOR="3.2"
+MAJOR="3"
 
 pip install --user --upgrade antsibull
 git clone git@github.com:ansible-community/ansible-build-data
 mkdir built
-BUILD_DATA_DIR="ansible-build-data/${MAJOR_MINOR}"
-if test -e "${BUILD_DATA_DIR}/ansible-${MAJOR_MINOR}.build" ; then
+
+# Ansible-2.10
+if test -e "ansible-build-data/${MAJOR_MINOR}" ; then
+  BUILD_DATA_DIR="ansible-build-data/${MAJOR_MINOR}"
   BUILDFILE="ansible-${MAJOR_MINOR}.build"
   DEPSFILE="ansible-${VERSION}.deps"
 else
-  BUILDFILE="acd-${MAJOR_MINOR}.build"
-  DEPSFILE="acd-${VERSION}.deps"
+  # Anything newer.  Uses semver so only the MAJOR is used.
+  BUILD_DATA_DIR="ansible-build-data/${MAJOR}"
+  BUILDFILE="ansible-${MAJOR}.build"
+  DEPSFILE="ansible-${VERSION}.deps"
 fi
+
 antsibull-build rebuild-single "${VERSION}" --data-dir "${BUILD_DATA_DIR}" --build-file "${BUILDFILE}" --deps-file "${DEPSFILE}" --sdist-dir built --debian
 
 #pip install twine
